<?php

namespace App\domain\amadeus;

use App\Traits\FileStorageTrait;
use Exception;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Log;

class CreateTSTFromPricing extends AmadeusRequestInSeries
{

    use FileStorageTrait;

    protected int $sequenceNumber;
    protected string $amadeusSessionId;
    protected string $amadeusSecurityToken;
    private array $passengerCriteria;

    public function __construct()
    {
        parent::__construct();

        $this->sequenceNumber = 5;
    }

    public function execute(array $passengerCriteria, string $amadeusSessionId, string $amadeusSecurityToken): array
    {
        try {
            $this->passengerCriteria = $passengerCriteria;
            $this->amadeusSessionId = $amadeusSessionId;
            $this->amadeusSecurityToken = $amadeusSecurityToken;

            $response = $this->createCurlRequest();

            self::storeInFile("xml", "2.5-create_tst_from_pricing_response", $response);

            $responseArray = $this->xmlResponseBodyToArray($response);

            self::storeInFile(
                "json", "2.5-create_tst_from_pricing-response", json_encode($responseArray)
            );

            return $responseArray;

        } catch (Exception $exception) {
            $e = "Error in create TST From Pricing execute:" . $exception->getMessage();
            Log::error($e);
            echo $e;

            return ['error' => $e];
        }
    }

    protected function generateXMLRequest(): string
    {
        $xmlRequest = $this->xmlHeader($this->sequenceNumber, $this->amadeusSessionId, $this->amadeusSecurityToken) .
            "
            <soap:Body>

                <Ticket_CreateTSTFromPricing>
                " . $this->generatePSANodeList() . "
                </Ticket_CreateTSTFromPricing>

            </soap:Body>
        </soap:Envelope>
        ";

        self::storeInFile("xml", "2.5-create_tst_from_pricing-request", $xmlRequest);

        return $xmlRequest;
    }

    protected function action(): string
    {
        return "http://webservices.amadeus.com/TAUTCQ_04_1_1A";
    }

    protected function generatePSANodeList(): string
    {
//        $adultsAndChildren = Collection::wrap($this->passengerCriteria)
//            ->whereIn("passengerTypeCode", ["ADT", "CHD"])
//            ->values();

        $xml = "";

        for ($pax = 1; $pax <= count($this->passengerCriteria); $pax++) {
            $xml .= "
                <psaList>
                    <itemReference>
                      <referenceType>TST</referenceType>
                      <uniqueReference>$pax</uniqueReference>
                    </itemReference>
                </psaList>";
        }

        return $xml;
    }
}
