<?php

namespace App\domain\amadeus;

use App\Traits\FileStorageTrait;
use Exception;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Log;

class QueryPNRRetrieveAction extends AmadeusRequestStateless
{
    use FileStorageTrait;

    protected string $controlNumber;
    private int $sequenceNumber;

    public function __construct()
    {
        parent::__construct();

        $this->sequenceNumber = 0;
    }

    public function execute(string $controlNumber): array
    {

        try {
            $this->controlNumber = $controlNumber;


            $response = $this->createCurlRequest();

            self::storeInFile("xml", "3.0-pnr-retrieve-response", $response);

            $responseArray = $this->xmlResponseBodyToArray($response);

            self::storeInFile(
                "json", "3.0-pnr-retrieve-response", json_encode($responseArray)
            );


            return $responseArray;

        } catch (Exception $exception) {
            $e = "Error in 3.0-pnr-retrieve:" . $exception->getMessage();
            Log::error($e);
            echo $e;

            return ["error" => $e];
        }
    }
    protected function generateXMLRequest(): string
    {
        $xmlRequest = $this->xmlHeader() . "
            <soap:Body>

                <PNR_Retrieve>
                  <retrievalFacts>
                    <retrieve>
                      <type>2</type>
                    </retrieve>
                    <reservationOrProfileIdentifier>
                      <reservation>
                        <controlNumber>{$this->controlNumber}</controlNumber>
                      </reservation>
                    </reservationOrProfileIdentifier>
                  </retrievalFacts>
                </PNR_Retrieve>
            </soap:Body>

        </soap:Envelope>";

        self::storeInFile("xml", "3.0-pnr-retrieve-request", $xmlRequest);

        return $xmlRequest;
    }

    protected function action(): string
    {
        return "http://webservices.amadeus.com/PNRRET_21_1_1A";
    }
}
